High level Bluetooth Low Energy API and radio abstraction layer

Dependencies:   nRF51822

Dependents:   LinkNode_LIS3DH

Fork of BLE_API by Bluetooth Low Energy

Revision:
710:b2e1a2660ec2
Parent:
671:33ec93d25695
--- a/services/LinkLossService.h	Fri Jun 19 15:53:06 2015 +0100
+++ b/services/LinkLossService.h	Fri Jun 19 15:53:28 2015 +0100
@@ -37,9 +37,9 @@
 
     /**
      * @param[ref] ble
      *               BLE object for the underlying controller.
      */
-    LinkLossService(BLE &bleIn, callback_t callbackIn, AlertLevel_t levelIn = NO_ALERT) :
+    LinkLossService(BLEDevice &bleIn, callback_t callbackIn, AlertLevel_t levelIn = NO_ALERT) :
         ble(bleIn),
         alertLevel(levelIn),
         callback(callbackIn),
@@ -80,7 +80,7 @@
      * @param[in] params
      *     Information about the characterisitc being updated.
      */
-    virtual void onDataWritten(const GattWriteCallbackParams *params) {
+    virtual void onDataWritten(const GattCharacteristicWriteCBParams *params) {
         if (params->charHandle == alertLevelChar.getValueHandle()) {
             alertLevel = *reinterpret_cast<const AlertLevel_t *>(params->data);
         }
@@ -92,8 +92,8 @@
         }
     }
 
-protected:
-    BLE          &ble;
+private:
+    BLEDevice    &ble;
     AlertLevel_t  alertLevel;
     callback_t    callback;
@@ -37,9 +37,9 @@
     /**
      * @param[ref] ble
-     *               BLE object for the underlying controller.
+     *                 BLEDevice object for the underlying controller.
      */